@@ -1,9 +1,9 @@
-from libtrust.keys.rs_key import RSAPrivateKey, RSAPublicKey
-from libtrust.keys.ec_key import ECPublicKey, ECPrivateKey
 from libtrust.jsonsign import JSONSignature
-from libtrust.keys import rs_key, ec_key
+from libtrust.keys import ec_key, rs_key
+from libtrust.keys.ec_key import ECPrivateKey, ECPublicKey
+from libtrust.keys.rs_key import RSAPrivateKey, RSAPublicKey
 
-__version__ = "1.0.4"
+__version__ = "1.0.5"
 
 
 __all__ = [
@@ -12,4 +12,6 @@ __all__ = [
     "ECPublicKey",
     "RSAPublicKey",
     "RSAPrivateKey",
+    "ec_key",
+    "rs_key",
 ]
